local augroup = require('helpers.augroup')

-- for each filetype autoformat on save
-- TODO can automatically gather from formatter table keys?
local filetypes =
    'bash,cpp,go,html,javascript,lua,python,rust,sh,typescript,zsh'
augroup({
    {
        'FileType', filetypes, 'autocmd', 'BufWritePost', '<buffer>',
        'FormatWrite'
    }
}, 'formatonsave')

local prettierfmt = {
    function()
        return {
            exe = "prettier",
            args = {
                "--stdin-filepath", vim.api.nvim_buf_get_name(0),
                '--single-quote'
            },
            stdin = true
        }
    end
}
local shfmt = {
    function() return {exe = "shfmt", args = {"-i 4"}, stdin = true} end
}

require('formatter').setup({
    logging = false,
    filetype = {
        bash = shfmt,
        cpp = {
            function()
                return {
                    exe = "clang-format",
                    args = {},
                    stdin = true,
                    cwd = vim.fn.expand('%:p:h') -- Run clang-format in cwd of the file.
                }
            end
        },
        go = {function() return {exe = "goimports", stdin = true} end},
        html = prettierfmt,
        javascript = prettierfmt,
        lua = {
            function()
                return {
                    exe = "lua-format",
                    args = {"--indent-width", 4},
                    stdin = true
                }
            end
        },
        python = {
            function()
                return {exe = "black", args = {"-"}, stdin = true}
            end
        },
        rust = {
            function()
                return {exe = "rustfmt", args = {"--emit=stdout"}, stdin = true}
            end
        },
        sh = shfmt,
        typescript = prettierfmt,
        zsh = shfmt
    }
})
